@@ -2,8 +2,9 @@ import os
 import sys
 import json
 import time
-import importlib
 import argparse
+import tempfile
+import importlib
 from typing import Optional, Dict, List
 from datetime import datetime
 
@@ -70,6 +71,10 @@ class JobBuilder():
     def resource_per_trial(self):
         return self._resource_per_trial
     
+    @property
+    def resource(self):
+        return self._resource
+    
     @resource_per_trial.setter
     def resource_per_trial(self, value):
         resource = JobBuilder.get_resource_info()
@@ -89,6 +94,7 @@ class JobBuilder():
         print('INFO: Each trial will use {} GPU(s) resource'.format(resource_per_trial['gpu']))
         print('INFO: Each trial will use {} CPU(s) resource'.format(resource_per_trial['cpu']))
         self._resource_per_trial = resource_per_trial
+        self._resource = resource
 
         
     @property
@@ -171,6 +177,7 @@ class JobBuilder():
         self.scripts_path = os.getcwd()
         self.search_points = None
         self.summary_fname = kGridSiteMetadataFileName
+        self._resource = {"cpu": 0, "gpu": 0}
 
         
     @staticmethod
@@ -336,7 +343,8 @@ class JobBuilder():
         # save something to prevent looping job
         with open(kGridSiteMetadataFileName,'w') as output:
             json.dump({}, output)
-            
+        
+        temp_dir = tempfile.TemporaryDirectory()
         # HPO starts
         try:
             
@@ -348,17 +356,25 @@ class JobBuilder():
                 extracted_files = helper.extract_tarball(datadir, datadir)
                 
             ray.init(include_dashboard=False)
-#           lru_evict=True            
+#           lru_evict=True      
+            if not self.log_dir:
+                local_dir = os.path.join(temp_dir.name, 'log')
+            else:
+                local_dir = self.log_dir
+            if self.num_trials == -1:
+                num_samples = max(self.resource.get('gpu'), 1)
+            else:
+                num_samples = self.num_trials
             analysis = tune.run(
                 model,
                 name=self.project_name,
                 scheduler=scheduler,
                 search_alg=algorithm,
                 config=tune_config_space,
-                num_samples=self.num_trials,
+                num_samples=num_samples,
                 resources_per_trial=self.resource_per_trial,
                 verbose=self.verbose,
-                local_dir=self.log_dir,
+                local_dir=local_dir,
                 loggers=loggers,
                 stop=self.stop)
 #                sync_to_driver=False,
@@ -377,7 +393,8 @@ class JobBuilder():
         print("Best config: ", self.best_config)
         print("Time taken in seconds: ", self.total_time)
         
-        print("INFO: Ray Tune log files are saved at {}".format(self.log_dir))
+        if self.log_dir:
+            print("INFO: Ray Tune log files are saved at {}".format(self.log_dir))
 
         df = analysis.dataframe(metric=self.metric, mode=self.mode)
 
@@ -395,6 +412,7 @@ class JobBuilder():
 
         # reset environment
         hpogrid.reset()
+        temp_dir.cleanup()
     
     def get_loggers(self):
         from ray.tune.logger import NoopLogger, MLFLowLogger
@@ -436,7 +454,7 @@ class JobBuilder():
         job.num_trials = config['hpo_config']['num_trials']
         job.max_concurrent = config['hpo_config']['max_concurrent']
         job.verbose = config['hpo_config']['verbose']
-        job.log_dir = config['hpo_config']['log_dir']
+        job.log_dir = config['hpo_config'].get('log_dir', None)
         job.stop = config['hpo_config'].get('stop', None)
         job.resource_per_trial = config['hpo_config'].get('resource', None)
         job.extra_metrics = config['hpo_config'].get('extra_metrics', None)
