@@ -7,7 +7,7 @@ from hpogrid.generator.base_generator import Generator
 from hpogrid.search_space.ax_space import AxSpace
 
 class AxGenerator(Generator):
-    def get_searcher(self, search_space:Dict, metric:str, mode:str):
+    def get_searcher(self, search_space:Dict, metric:str, mode:str, **args):
         ax_client = AxClient(enforce_sequential_optimization=False, verbose_logging=False)
         search_space = AxSpace(search_space).get_search_space()
         if mode == 'max':
