@@ -1,10 +1,7 @@
-import copy
+import itertools
 from typing import List, Dict
 
-from ax.service.ax_client import AxClient
-
 from hpogrid.generator.base_generator import Generator
-from hpogrid.search_space.ax_space import AxSpace
 
 class GridGenerator(Generator):
     def get_searcher(self, search_space:Dict, metric:str, mode:str, **args):
@@ -28,7 +25,7 @@ class GridGenerator(Generator):
     def ask(self, n_points:int =None):
         points = []
         if n_points > len(self.searcher):
-            n_points = len(self.searcher):
+            n_points = len(self.searcher)
         for i in range(n_points):
             points.append({ k:v for k,v in zip(self.labels, self.searcher[i])})
         return points
\ No newline at end of file
